@@ -329,7 +329,7 @@ private:
 
     //*@}
 
-    //*@name complex ontrols specialized functions
+    //*@name complex controls specialized functions
     //@{
     bool drawGroupBoxComplexControl(const QStyleOptionComplex *, QPainter *, const QWidget *) const;
     bool drawToolButtonComplexControl(const QStyleOptionComplex *, QPainter *, const QWidget *) const;
@@ -457,7 +457,7 @@ private:
     This is needed to implement custom number of buttons in scrollbars,
     as well as proper mouse-hover
     */
-    inline bool preceeds(const QPoint &, const QRect &, const QStyleOption *) const;
+    inline bool precedes(const QPoint &, const QRect &, const QStyleOption *) const;
 
     //* return which arrow button is hit by point for scrollbar double buttons
     inline QStyle::SubControl scrollBarHitTest(const QRect &, const QPoint &, const QStyleOption *) const;
@@ -536,7 +536,7 @@ private:
 };
 
 //_________________________________________________________________________
-bool Style::preceeds(const QPoint &point, const QRect &bound, const QStyleOption *option) const
+bool Style::precedes(const QPoint &point, const QRect &bound, const QStyleOption *option) const
 {
     if (option->state & QStyle::State_Horizontal) {
         if (option->direction == Qt::LeftToRight) {
